# ostRAT

![PyPI](https://img.shields.io/pypi/v/ostrat?color=orange) ![Python 3.9, 3.10](https://img.shields.io/pypi/pyversions/clubhouse?color=blueviolet)  ![License](https://img.shields.io/pypi/l/ostrat?color=blueviolet)

**Open Source Telegram RAT** - Remote PC access via Telegram Bot.

**SourceForge -** [ostRAT | SourceForge](https://sourceforge.net/projects/ostrat/files/)

**PyPi -** [ostRAT | PyPi](https://pypi.org/project/ostrat/)

## Installation

Install the current version with [PyPI](https://pypi.org/project/ostrat/):

```bash

pip install ostrat

```

Or SourceForge: [ostRAT download | SourceForge](https://sourceforge.net/projects/ostrat/)
  
## Usage

After installing ostrat, create a .py file and type "import ostrat" ​​into it. Save and run it.<br/>
Enter id and token, system.py in local directory<br/>
Run the system.py file and use the ostrat.

## Settings

You can get a token from @BotFather in Telegram.  
It looks like "1111100000:AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAaaaaa" 
 
You can get a id from @myidbot in Telegram.  
It looks like "123456789"

## Example

```python

import ostrat
ostrat.create()

```

## Contributing

Bugs, reports and/or pull requests are welcome.

## License

OSI-Approved Open Source » GNU General Public License version 3.0 [GPLv3](https://www.gnu.org/licenses/gpl-3.0.html)

## Author
Alexey Avilov
Telegram: [@Iexek](https://t.me/Iexek)
2022 lexek
